@@ -23,7 +23,7 @@ SUBMISSION_URL = u"submission_url"
 DEFAULT_LANGUAGE = u"default_language"
 LABEL = u"label"
 HINT = u"hint"
-CLASS_ATTR = u"class"
+STYLE = u"style"
 
 BIND = u"bind"#TODO: What should I do with the nested types? (readonly and relevant)
 MEDIA = u"media"
